==> app-compat-0.1.22-2022312211851.tgz: package/CHANGELOG.md <==
# @firebase/app-compat

## 0.1.22-2022312211851

### Patch Changes

- Updated dependencies [[`e9e5f6b3c`](https://github.com/firebase/firebase-js-sdk/commit/e9e5f6b3ca9d61323b22f87986d9959f5297ec59)]:
  - @firebase/util@1.5.2-2022312211851
  - @firebase/app@0.7.21-2022312211851
  - @firebase/component@0.5.13-2022312211851

## 0.1.21

### Patch Changes

- Updated dependencies [[`3198d58dc`](https://github.com/firebase/firebase-js-sdk/commit/3198d58dcedbf7583914dbcc76984f6f7df8d2ef)]:
  - @firebase/util@1.5.1
  - @firebase/app@0.7.20
  - @firebase/component@0.5.12

## 0.1.20

### Patch Changes

- Updated dependencies [[`2d672cead`](https://github.com/firebase/firebase-js-sdk/commit/2d672cead167187cb714cd89b638c0884ba58f03), [`927c1afc1`](https://github.com/firebase/firebase-js-sdk/commit/927c1afc103e4f9b8a75320d3946a4c840445a2a)]:
  - @firebase/app@0.7.19
  - @firebase/util@1.5.0
  - @firebase/component@0.5.11

## 0.1.19

### Patch Changes

- Updated dependencies [[`1588990b7`](https://github.com/firebase/firebase-js-sdk/commit/1588990b7fb06b6fa545c0d478663e137ec0ea07)]:
  - @firebase/app@0.7.18

## 0.1.18

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.17

## 0.1.17

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.16

## 0.1.16

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.15

## 0.1.15

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.14

## 0.1.14

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.13

## 0.1.13

### Patch Changes

- Updated dependencies [[`3b481f572`](https://github.com/firebase/firebase-js-sdk/commit/3b481f572456e1eab3435bfc25717770d95a8c49)]:
  - @firebase/util@1.4.3
  - @firebase/app@0.7.12
  - @firebase/component@0.5.10

## 0.1.12

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.11

## 0.1.11

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.10

## 0.1.10

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.9

## 0.1.9

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.8

## 0.1.8

### Patch Changes

- [`3281315fa`](https://github.com/firebase/firebase-js-sdk/commit/3281315fae9c6f535f9d5052ee17d60861ea569a) [#5708](https://github.com/firebase/firebase-js-sdk/pull/5708) (fixes [#1487](https://github.com/firebase/firebase-js-sdk/issues/1487)) - Update build scripts to work with the exports field

- Updated dependencies [[`3281315fa`](https://github.com/firebase/firebase-js-sdk/commit/3281315fae9c6f535f9d5052ee17d60861ea569a)]:
  - @firebase/app@0.7.7
  - @firebase/component@0.5.9
  - @firebase/logger@0.3.2
  - @firebase/util@1.4.2

## 0.1.7

### Patch Changes

- [`2322b6023`](https://github.com/firebase/firebase-js-sdk/commit/2322b6023c628cd9f4f4172767c17d215dd91684) [#5693](https://github.com/firebase/firebase-js-sdk/pull/5693) - Add exports field to all packages

- Updated dependencies [[`2322b6023`](https://github.com/firebase/firebase-js-sdk/commit/2322b6023c628cd9f4f4172767c17d215dd91684)]:
  - @firebase/app@0.7.6
  - @firebase/component@0.5.8
  - @firebase/logger@0.3.1
  - @firebase/util@1.4.1

## 0.1.6

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.5

## 0.1.5

### Patch Changes

- Updated dependencies [[`93795c780`](https://github.com/firebase/firebase-js-sdk/commit/93795c7801d6b28ccbbe5855fd2f3fc377b1db5f)]:
  - @firebase/app@0.7.4

## 0.1.4

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.3

## 0.1.3

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.2

## 0.1.2

### Patch Changes

- Updated dependencies [[`a99943fe3`](https://github.com/firebase/firebase-js-sdk/commit/a99943fe3bd5279761aa29d138ec91272b06df39), [`b835b4cba`](https://github.com/firebase/firebase-js-sdk/commit/b835b4cbabc4b7b180ae38b908c49205ce31a422)]:
  - @firebase/logger@0.3.0
  - @firebase/util@1.4.0
  - @firebase/app@0.7.1
  - @firebase/component@0.5.7

## 0.1.1

### Patch Changes

- [`cd15df0d1`](https://github.com/firebase/firebase-js-sdk/commit/cd15df0d1f51110f448e4284244b06be8d37f1c3) [#5400](https://github.com/firebase/firebase-js-sdk/pull/5400) (fixes [#2903](https://github.com/firebase/firebase-js-sdk/issues/2903)) - Fix cjs builds by removing the named export from app-compat

* [`1b33fda40`](https://github.com/firebase/firebase-js-sdk/commit/1b33fda40ddc48e9ed28e94607bf100159f5b80e) [#5385](https://github.com/firebase/firebase-js-sdk/pull/5385) (fixes [#5382](https://github.com/firebase/firebase-js-sdk/issues/5382)) - Remove private types in app-compat

## 0.1.0

### Minor Changes

- [`cdada6c68`](https://github.com/firebase/firebase-js-sdk/commit/cdada6c68f9740d13dd6674bcb658e28e68253b6) [#5345](https://github.com/firebase/firebase-js-sdk/pull/5345) (fixes [#5015](https://github.com/firebase/firebase-js-sdk/issues/5015)) - Release modularized SDKs

### Patch Changes

- Updated dependencies [[`cdada6c68`](https://github.com/firebase/firebase-js-sdk/commit/cdada6c68f9740d13dd6674bcb658e28e68253b6)]:
  - @firebase/app@0.7.0

==> app-compat-0.1.39.tgz: package/CHANGELOG.md <==
# @firebase/app-compat

## 0.1.39

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.8.4

## 0.1.38

### Patch Changes

- [`4af28c1a4`](https://github.com/firebase/firebase-js-sdk/commit/4af28c1a42bd25ce2353f694ca1724c6101cbce5) [#6682](https://github.com/firebase/firebase-js-sdk/pull/6682) - Upgrade TypeScript to 4.7.4.

- Updated dependencies [[`4af28c1a4`](https://github.com/firebase/firebase-js-sdk/commit/4af28c1a42bd25ce2353f694ca1724c6101cbce5)]:
  - @firebase/app@0.8.3
  - @firebase/component@0.5.21
  - @firebase/logger@0.3.4
  - @firebase/util@1.7.3

## 0.1.37

### Patch Changes

- Updated dependencies [[`807f06aa2`](https://github.com/firebase/firebase-js-sdk/commit/807f06aa26438a91aaea08fd38efb6c706bb8a5d)]:
  - @firebase/util@1.7.2
  - @firebase/app@0.8.2
  - @firebase/component@0.5.20

## 0.1.36

### Patch Changes

- Updated dependencies [[`171b78b76`](https://github.com/firebase/firebase-js-sdk/commit/171b78b762826a640d267dd4dd172ad9459c4561), [`29d034072`](https://github.com/firebase/firebase-js-sdk/commit/29d034072c20af394ce384e42aa10a37d5dfcb18)]:
  - @firebase/util@1.7.1
  - @firebase/app@0.8.1
  - @firebase/component@0.5.19

## 0.1.35

### Patch Changes

- Updated dependencies [[`fdd4ab464`](https://github.com/firebase/firebase-js-sdk/commit/fdd4ab464b59a107bdcc195df3f01e32efd89ed4)]:
  - @firebase/app@0.8.0
  - @firebase/util@1.7.0
  - @firebase/component@0.5.18

## 0.1.34

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.33

## 0.1.33

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.32

## 0.1.32

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.31

## 0.1.31

### Patch Changes

- Updated dependencies [[`82a6add13`](https://github.com/firebase/firebase-js-sdk/commit/82a6add1354fe7e4ac1d444157ac027cdd41da6e)]:
  - @firebase/app@0.7.30

## 0.1.30

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.29

## 0.1.29

### Patch Changes

- Updated dependencies [[`b12af44a5`](https://github.com/firebase/firebase-js-sdk/commit/b12af44a5c7500e1192d6cc1a4afc4d77efadbaf)]:
  - @firebase/util@1.6.3
  - @firebase/app@0.7.28
  - @firebase/component@0.5.17

## 0.1.28

### Patch Changes

- Updated dependencies [[`efe2000fc`](https://github.com/firebase/firebase-js-sdk/commit/efe2000fc499e2c85c4e5e0fef6741ff3bad2eb0)]:
  - @firebase/util@1.6.2
  - @firebase/app@0.7.27
  - @firebase/component@0.5.16

## 0.1.27

### Patch Changes

- [`2cd1cc76f`](https://github.com/firebase/firebase-js-sdk/commit/2cd1cc76f2a308135cd60f424fe09084a34b5cb5) [#6307](https://github.com/firebase/firebase-js-sdk/pull/6307) (fixes [#6300](https://github.com/firebase/firebase-js-sdk/issues/6300)) - fix: add type declarations to exports field

- Updated dependencies [[`2cd1cc76f`](https://github.com/firebase/firebase-js-sdk/commit/2cd1cc76f2a308135cd60f424fe09084a34b5cb5)]:
  - @firebase/app@0.7.26
  - @firebase/component@0.5.15
  - @firebase/logger@0.3.3
  - @firebase/util@1.6.1

## 0.1.26

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.25

## 0.1.25

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.24

## 0.1.24

### Patch Changes

- Updated dependencies [[`9c5c9c36d`](https://github.com/firebase/firebase-js-sdk/commit/9c5c9c36da80b98b73cfd60ef2e2965087e9f801)]:
  - @firebase/util@1.6.0
  - @firebase/app@0.7.23
  - @firebase/component@0.5.14

## 0.1.23

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.22

## 0.1.22

### Patch Changes

- Updated dependencies [[`e9e5f6b3c`](https://github.com/firebase/firebase-js-sdk/commit/e9e5f6b3ca9d61323b22f87986d9959f5297ec59)]:
  - @firebase/util@1.5.2
  - @firebase/app@0.7.21
  - @firebase/component@0.5.13

## 0.1.21

### Patch Changes

- Updated dependencies [[`3198d58dc`](https://github.com/firebase/firebase-js-sdk/commit/3198d58dcedbf7583914dbcc76984f6f7df8d2ef)]:
  - @firebase/util@1.5.1
  - @firebase/app@0.7.20
  - @firebase/component@0.5.12

## 0.1.20

### Patch Changes

- Updated dependencies [[`2d672cead`](https://github.com/firebase/firebase-js-sdk/commit/2d672cead167187cb714cd89b638c0884ba58f03), [`927c1afc1`](https://github.com/firebase/firebase-js-sdk/commit/927c1afc103e4f9b8a75320d3946a4c840445a2a)]:
  - @firebase/app@0.7.19
  - @firebase/util@1.5.0
  - @firebase/component@0.5.11

## 0.1.19

### Patch Changes

- Updated dependencies [[`1588990b7`](https://github.com/firebase/firebase-js-sdk/commit/1588990b7fb06b6fa545c0d478663e137ec0ea07)]:
  - @firebase/app@0.7.18

## 0.1.18

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.17

## 0.1.17

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.16

## 0.1.16

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.15

## 0.1.15

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.14

## 0.1.14

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.13

## 0.1.13

### Patch Changes

- Updated dependencies [[`3b481f572`](https://github.com/firebase/firebase-js-sdk/commit/3b481f572456e1eab3435bfc25717770d95a8c49)]:
  - @firebase/util@1.4.3
  - @firebase/app@0.7.12
  - @firebase/component@0.5.10

## 0.1.12

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.11

## 0.1.11

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.10

## 0.1.10

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.9

## 0.1.9

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.8

## 0.1.8

### Patch Changes

- [`3281315fa`](https://github.com/firebase/firebase-js-sdk/commit/3281315fae9c6f535f9d5052ee17d60861ea569a) [#5708](https://github.com/firebase/firebase-js-sdk/pull/5708) (fixes [#1487](https://github.com/firebase/firebase-js-sdk/issues/1487)) - Update build scripts to work with the exports field

- Updated dependencies [[`3281315fa`](https://github.com/firebase/firebase-js-sdk/commit/3281315fae9c6f535f9d5052ee17d60861ea569a)]:
  - @firebase/app@0.7.7
  - @firebase/component@0.5.9
  - @firebase/logger@0.3.2
  - @firebase/util@1.4.2

## 0.1.7

### Patch Changes

- [`2322b6023`](https://github.com/firebase/firebase-js-sdk/commit/2322b6023c628cd9f4f4172767c17d215dd91684) [#5693](https://github.com/firebase/firebase-js-sdk/pull/5693) - Add exports field to all packages

- Updated dependencies [[`2322b6023`](https://github.com/firebase/firebase-js-sdk/commit/2322b6023c628cd9f4f4172767c17d215dd91684)]:
  - @firebase/app@0.7.6
  - @firebase/component@0.5.8
  - @firebase/logger@0.3.1
  - @firebase/util@1.4.1

## 0.1.6

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.5

## 0.1.5

### Patch Changes

- Updated dependencies [[`93795c780`](https://github.com/firebase/firebase-js-sdk/commit/93795c7801d6b28ccbbe5855fd2f3fc377b1db5f)]:
  - @firebase/app@0.7.4

## 0.1.4

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.3

## 0.1.3

### Patch Changes

- Updated dependencies []:
  - @firebase/app@0.7.2

## 0.1.2

### Patch Changes

- Updated dependencies [[`a99943fe3`](https://github.com/firebase/firebase-js-sdk/commit/a99943fe3bd5279761aa29d138ec91272b06df39), [`b835b4cba`](https://github.com/firebase/firebase-js-sdk/commit/b835b4cbabc4b7b180ae38b908c49205ce31a422)]:
  - @firebase/logger@0.3.0
  - @firebase/util@1.4.0
  - @firebase/app@0.7.1
  - @firebase/component@0.5.7

## 0.1.1

### Patch Changes

- [`cd15df0d1`](https://github.com/firebase/firebase-js-sdk/commit/cd15df0d1f51110f448e4284244b06be8d37f1c3) [#5400](https://github.com/firebase/firebase-js-sdk/pull/5400) (fixes [#2903](https://github.com/firebase/firebase-js-sdk/issues/2903)) - Fix cjs builds by removing the named export from app-compat

* [`1b33fda40`](https://github.com/firebase/firebase-js-sdk/commit/1b33fda40ddc48e9ed28e94607bf100159f5b80e) [#5385](https://github.com/firebase/firebase-js-sdk/pull/5385) (fixes [#5382](https://github.com/firebase/firebase-js-sdk/issues/5382)) - Remove private types in app-compat

## 0.1.0

### Minor Changes

- [`cdada6c68`](https://github.com/firebase/firebase-js-sdk/commit/cdada6c68f9740d13dd6674bcb658e28e68253b6) [#5345](https://github.com/firebase/firebase-js-sdk/pull/5345) (fixes [#5015](https://github.com/firebase/firebase-js-sdk/issues/5015)) - Release modularized SDKs

### Patch Changes

- Updated dependencies [[`cdada6c68`](https://github.com/firebase/firebase-js-sdk/commit/cdada6c68f9740d13dd6674bcb658e28e68253b6)]:
  - @firebase/app@0.7.0
